pub struct ClientConfig {
pub http_timeout: Duration,
pub default_headers: HeaderMap,
pub resolve_ip: Option<IpAddr>,
}Expand description
Configuration for the API client. Allows users to customize its behaviour.
Fields
http_timeout: DurationThe maximum time limit for an API request. If a request takes longer than this, it will be cancelled. Note: this configuration has no effect when the target is wasm32.
default_headers: HeaderMapA default set of HTTP headers which will be sent with each API request.
resolve_ip: Option<IpAddr>A specific IP to use when establishing a connection Note: this configuration has no effect when the target is wasm32.